@@ -103,13 +103,13 @@ function doShowMessages(){
         $('MessageList').style.display='none';
         $('FrameBottom').style.height='30px';
         
-        $('NewMessage').innerHTML = '[Tip] Click here to view system message and user say hi.';
+        $('NewMessage').innerHTML = getLangs('Tip_Bottom');
     }else{
         $('FrameCenter').style.display='none';
         $('MessageList').style.display='block';
         $('FrameBottom').style.height='360px';
         
-        $('NewMessage').innerHTML = '[Tip] Click here to hidden message ui.';
+        $('NewMessage').innerHTML = getLangs('Tip_Bottom_Hide');
     }
 }
 
@@ -165,7 +165,7 @@ function doSearchApp(){
     $('AppClassSummary').style.display='block';
     
     $('SelectClass').innerHTML = 'Search App: '+tmpSearchKeyword;
-    $('DownloadAppList').innerHTML = '<div class="Item Left">Please wait, loading...</div>';
+    $('DownloadAppList').innerHTML = '<div class="Item Left">'+getLangs('Loading')+'</div>';
     
     
     go('UI.html#downloadapps_searchapp_'+tmpSearchKeyword);
@@ -177,8 +177,8 @@ function doAppList(strObj, strClassID){
     $('DownloadAppList').style.display='block';
     $('AppClassSummary').style.display='block';
     
-    $('SelectClass').innerHTML = 'Select Class: '+strObj.innerText;
-    $('DownloadAppList').innerHTML = '<div class="Item Left">Please wait, loading...</div>';
+    $('SelectClass').innerHTML = getLangs('SelectClass') + ': '+strObj.innerText;
+    $('DownloadAppList').innerHTML = '<div class="Item Left">'+getLangs('Loading')+'</div>';
     VarSelectClassID = strClassID;
     VarClassOrderBy = 'new';
     
@@ -197,7 +197,7 @@ function doLoadAppList(strReload, strSearch){
     }
     if (!tmpRe){
         if ((strReload) || (strSearch)){
-            $('DownloadAppList').innerHTML = '<div class="Item Left">Sorry, Cann\'t load apps.</div>';
+            $('DownloadAppList').innerHTML = '<div class="Item Left">'+getLangs('CannotLoadApps')+'</div>';
         }else{
             go('UI.html#downloadapps_loadapps_'+VarSelectClassID+'_'+VarClassOrderBy);
             doLoadAppList(true);
@@ -212,14 +212,14 @@ function doLoadAppList(strReload, strSearch){
             tmpHTML += '               <img width="26" height="26" src="'+tmpRe[i].d_pic+'">';
             tmpHTML += '           </div>';
             tmpHTML += '           <div class="AppName Left">';
-            tmpHTML += '               '+tmpRe[i].d_topic+' (Size:'+tmpRe[i].d_size+'  Down:'+tmpRe[i].d_counter+')';
+            tmpHTML += '               '+tmpRe[i].d_topic+' ('+getLangs('Size')+':'+tmpRe[i].d_size+'  '+getLangs('Down')+':'+tmpRe[i].d_counter+')';
             tmpHTML += '           </div>';
             tmpHTML += '           <div class="AppBtn Right">';
             tmpHTML += '               [View Details]';
             tmpHTML += '           </div>';
             tmpHTML += '       </div>';
             tmpHTML += '       <div class="AppSummary Left hide" id="AppSummary_'+tmpRe[i].d_id+'">';
-            tmpHTML += '           <div class="Remark Left">Translator:'+tmpRe[i].username+' Update: '+tmpRe[i].d_tim+'<br> '+tmpRe[i].d_remark+'</div>';
+            tmpHTML += '           <div class="Remark Left">'+getLangs('Translator')+':'+tmpRe[i].username+' '+getLangs('UpdateDate')+': '+tmpRe[i].d_tim+'<br> '+tmpRe[i].d_remark+'</div>';
             tmpHTML += '           <div class="Download Left" onclick="javascript:doDownloadApp('+tmpRe[i].d_id+');"><img src="images/icon_download.jpg"></div>';
             tmpHTML += '       </div>';
             
@@ -254,8 +254,7 @@ function doSearchPackageSubmit(){
     VarSearchKeyword = tmpSearchKeyword;
     
     $('ResultPackageList').style.display='block';
-    $('ResultPackageList').innerHTML = '<div class="Item Left">Please wait, searching...</div>';
-    
+    $('ResultPackageList').innerHTML = '<div class="Item Left">'+getLangs('Loading')+'</div>';
     
     go('UI.html#searchpackage_keyword_'+tmpSearchKeyword);
     setTimeout('doLoadSearchPachageResult()',500);
@@ -266,7 +265,7 @@ function doLoadSearchPachageResult(){
 }
 
 function doInstallPackage(strPackage){
-	var tmptrue=window.confirm('Install it?');
+	var tmptrue=window.confirm(getLangs('InstallIt'));
 	if (tmptrue) {
         go('UI.html#searchpackage_install_'+strPackage);
 	}
@@ -287,7 +286,7 @@ function doDebugApps(){
 
 function doPrviewAppInfo(strApp, strIcon){
     $('AppIcon').src='file://'+strIcon;
-    $('AppName').innerHTML='App Name: '+strApp;
+    $('AppName').innerHTML=getLangs('AppName') + ': '+strApp;
     $('AppNameShow').innerHTML=strApp;
     $('AppRun').href='#debugapps_run_'+strApp;
     
@@ -337,7 +336,7 @@ function doLoadUsers(strReload, strRefresh){
     
     if (!tmpRe){
         if (strReload){
-            $('AroundUserList').innerHTML = '<div class="Item Left">Sorry, Cann\'t load users.</div>';
+            $('AroundUserList').innerHTML = '<div class="Item Left">'+getLangs('CannotLoadUsers')+'</div>';
         }else{
             go('UI.html#allmaemousers_load_users');
             doLoadUsers(true);
@@ -381,14 +380,14 @@ function doGPSMapShow(strUid, strUsername, strGPS){
 
 
 function doSayHi(){
-	var tmpTrue=window.confirm('Confirm say \'Hi\' to this user?');
+	var tmpTrue=window.confirm(getLangs('SayHi'));
 	if (tmpTrue) {
         go('UI.html#account_sayhi_'+VarTarUserid);
 	}
 }
 
 function doUpdateGPS(){
-	var tmpTrue=window.confirm('Confirm update your gps data to maemoapp.com server?');
+	var tmpTrue=window.confirm(getLangs('UpdateGPS'));
 	if (tmpTrue) {
         go('UI.html#allmaemousers_update_gps');
 	}
@@ -459,6 +458,7 @@ function getCalcDistance(f,t){
 }
 
 
-
+function Langs(strKey) { document.write(_Langs[strKey]); }
+function getLangs(strKey) { return _Langs[strKey]; }
 function go(strURL) { location.href=strURL; setTimeout('doLoadMessages()',1000); }
 function $(){return document.getElementById?document.getElementById(arguments[0]):eval(arguments[0]);}
